# gFunctionLibrary
A submodule of the GLHE Design Tool, containing libraries of g-functions, access and accurate interpolation

The libraries of g-functions available are the following:

[ ] - Rectangles (including lines)
[ ] - Open rectangles
[ ] - L configuration
[ ] - U configuration
[x] - Zoned rectangles

# Documentation
See the documentation at <a href="https://gfunctionlibrary.readthedocs.io/en/latest/" target="_blank">ReadTheDocs</a>